HEIDI:
Previously on Project Runway...
Our Mary Kay challenge is your
first team challenge.
ALL:
Oh! [whooping]
Can I, um, put myself
in for the pitch?
I present a lot
in front of investors.
TIM:
Design team,
say hello to your investors.
HEIDI:
Hi, guys.
I'm representing
six of America's
top emerging fashion designers.
We're a collaborative group
of fashion designers,
spanning from California,
all the way to Paris, France.
♪ ♪
HEIDI:
House of Bouton,
you are the winning team.
And, Dexter, you are the winner
of this challenge.
Team Unity,
you are the losing team.
Who should go home?
I have to take accountability.
If there's anybody
that deserves to go home,
it's me.
HEIDI: Alex, I'm really sorry.
You're out.
♪ ♪
So, tell me, how's season 15
going so far?
Extraordinarily.
We have a...
really talented group
of designers.
The designers on the show
have the opportunity
to use this exposure
as a beginning of a platform.
Okay.
HEIDI:
I think they are
more fashion-forward.
-Mm.
-I feel like they're very,
-um, intense designers.
-Mm.
Very passionate.
They cry a lot.
TIM:
Hi!
It's your party!
Come on in, mill about.
-Oh, my God.
-Get a drink.
-What is going on here?
-Go to the bar.
-It's in the back.
-Look at this...
-Okay!
-Enjoy it. Look at you.
CORNELIUS: We walk
into the Absolut Elyx House,
and it is beautiful.
TIM:
I'll come with you.
NATHALIA:
It's just, like,
the fanciest place
I've ever been.
I see Heidi, and Zac and Nina.
CORNELIUS: There's a lot
of coppers and golds.
MAH-JING:
Crystals, flowers.
NATHALIA:
After working so much--
work, work, work, work, work--
having a party is really fun.
MAH-JING:
I don't want to think
about a needle and thread.
Oh, my God.
I'm just trying
to have a good time
and enjoy this party.
[singing excitedly]
-Is it good?
-It's so good!
Good.
♪ ♪
Mmm.
I'm Sydney.
-Nice to meet you.
-Pleasure. Nice to meet you.
TIM:
Lemara, this is Cornelius.
CORNELIUS:
Hi.
TIM: Nathalia,
I want you to meet Lauren.
Doing press is exciting.
LAUREN: How's the vibe been
on this season?
So far, it's been really great.
It makes me feel like,
"Oh, my God,
I'm on Project Runway."
NATHALIA: Actually, Cornelius--
he's one of my best friends.
We tried out together.
I've been telling him,
like, "I hope this
doesn't, like...
-like, mess with our friendship
after this." -Right.
Everyone, please come up here.
Join me for a toast.
Hello, everyone.
And welcome to
Elyx House New York.
I am Jonas Tahlin,
and I'm the CEO
for Absolut Elyx.
And we at Elyx
are so happy to have
such a wonderful group
of talented designers
with us here tonight.
I see that you're all drinking
from our signature
drinking vessel,
the Elyx copper pineapple.
And we've chosen copper
because our luxury vodka
is made by hand,
in a copper still from 1921.
Cheers!
Cheers. Thank you, Jonas.
-Bottom's up.
-[all laughing]
And I also want to welcome you
designers for coming today
to our little... party.
And as you know, martinis
go really well with a twist.
-[all chuckling nervously]
-Yeah.
And we like twists
on Project Runway, don't we?
-NATHALIA: We don't.
-[all laughing]
This is not just
a fun c*ck party.
This is also the beginning
of your next challenge.
Yeah.
In the spirit of Elyx,
you will each be creating
a luxurious c*ck dress.
ALL:
Ooh! [whooping]
TIM:
And, designers, look around,
because this magnificent space
is your inspiration.
You will have one day
for this challenge
-and a budget of $300 for Mood.
-[all gasping]
-Yes!
-Yes, $300!
[whooping]
All right, everyone,
let's start sketching.
♪ ♪
Inspiration.
LAURENCE: I'm sitting on a
beautiful Chesterfield couch,
and that's
my first inspiration.
I think it's right
in my alley.
JENNI:
It's very, like, 1920s in here.
The look that I'm designing
is definitely gonna coincide
with the vibe of the room.
It kind of reminds me
of something that would be,
you know, like, in the '20s.
TASHA: My girl is
getting c*ck, but just
not at the c*ck party
that everybody else is going to.
-May I have a slushie?
-Certainly.
Thank you!
I think,
"Well, what in this room
inspires me as a designer?"
And I look at my hand.
I'm holding
my copper pineapple
and I'm looking at that
drizzle down it.
I wanted to capitalize
off of the sweat technique.
I'm like, "that'd be dope
in a dress.
A drizzle down effect."
So, that's what I'm gonna do.
RIK:
So, I'm immediately inspired by
these bartenders'
leather aprons
that they're wearing.
So, I'm envisioning
a leather apron c*ck dress.
I don't think anybody else
is going to come up
with this type of look.
ERIN: And what is, like,
in Absolut Elyx?
-That's why... -That's why
there's all the copper.
I love copper.
It's so beautiful.
Instead of sketching, like, a
silhouette or anything specific,
I want to point out details
that I like.
There's, like, porcelain dolls
and the chandeliers
and the flamingo wallpaper
bathroom.
NATHALIA:
There's inspiration everywhere.
I have so many ideas,
but the common thread
amongst all the ideas
that I have
-are these crystals.
-[dings]
So I'm hoping that I can find
the fabric,
like the one I'm imagining,
at Mood.
Designers, sketching time is up.
Can you all gather round?
This has been
a wonderful experience
for all of us, I believe.
-DESIGNERS: Yeah.
-ERIN: It was awesome.
And you have... a whole day
tomorrow to work.
And I will meet you at Mood
in the morning.
All right!
Come on, Tim.
Thank you, pineapple.
♪ ♪
[Swatch barks]
TIM:
Off they go.
♪ ♪
TASHA:
We have a $300 budget.
-Ching ching.
-[cash register rings]
TIM:
Designers, time is up.
-No more shopping, everyone.
-Thank you.
All right, designers, let's head
back to the workroom.
Thank you, Mood!
-DESIGNERS: Thank you, Mood!
-TIM: Thank you.
-[indistinct conversations]
-[Dexter sighs]
♪ ♪
Now that is cool.
Doesn't it just have the essence
of what room we were in?
Yeah!
JENNI: This definitely looks
like the room, too, though.
-Like, there was a lot of glitz
in there. -Yeah.
I'm just thinking, like...
I mean, shiny is a color, right?
TIM:
All right, designers.
I will be in later to check in
with each of you.
Your models will be in after
that for a fitting.
And please take advantage
of the Brother sewing room.
All right?
You have until 10:00 tonight.
-Thank you.
-JENNI: Thank you.
NATHALIA:
Thank you.
NATHALIA: Why are you
throwing shade at me?
I didn't throw shade, Nathalia.
I just asked a question.
I was like,
-"Do you see yourself in it?"
-NATHALIA: I do.
CORNELIUS:
This is a good challenge
to really represent
you as a designer.
I just feel as though
she is not
hitting the mark
with this one.
If it doesn't look like me,
it just means
-I'm growing.
-Not necessarily.
Nathalia could be in trouble.
♪ ♪
ROBERI: We have to make
a c*ck dress
inspired by Absolut Elyx House.
I don't want to make
a classic c*ck dress.
I want the silhouette
to have something
more like a bell.
[bell rings]
TIM:
Hi, everyone.
-ERIN: Hello.
-Hey.
I'm eager to check in with you.
-How's Rik?
-Great.
It's my first time really making
a whole... leather... dress.
TIM:
I see the reference.
It was the aprons that
the waitstaff was wearing.
I did buy
lots of the leather paints.
So I was planning on maybe doing
-some type of wood grain.
-Yes. All right, Rik.
-I believe. Thank you.
-I appreciate it. Thank you.
ERIN:
I just, like, love copper,
so I really knew that I wanted
-to go with a copper look.
-Mm-hmm.
Kind of was going back and forth
between, like,
how I wanted
to use the feathers, 'cause I...
like, I like
the flamingo bathroom.
But I kind of wanted to, like,
put it into that copper tone.
Crazy bathroom!
I also got a bunch
of these crystal things.
The feathers
and this elaborate brocade,
-I think you've got enough
going on. -Okay. Thank you, Tim.
JENNI:
I was pretty inspired by
all the shiny stuff in there.
Lots of shiny stuff.
And also, I feel like it had
-a very speakeasy sort of thing.
-Mm-hmm. It did.
So I wanted to go
with a very simple silhouette.
-Okay. -And then
I've just been going in
and pinning
these shiny appliques.
Carry on!
-JENNI: Thank you.
-TIM: Thank you.
DEXTER: I thought
it would be really cool
to do, like,
a whole chocolate thing.
Well, chocolate brown
can be very chic.
And then I'm making
a little shoulder piece,
and I'm going to completely
cover it in chocolate fringe.
I feel there's something
very sophisticated
-about what you're doing
with the neck. -Okay.
And this, to me, is looking a
little Wild West, a little Cher.
I'm not real... like, remotely
afraid of it being more of like
a neck fringe situation
around the dress,
instead of messing
with the girl's
-arms and shoulders.
-I'm excited about this.
-All right! Right on.
-Thank you.
Thank you!
-TIM: Brik.
-Hi, Tim.
-This is over this?
-Yes, sir.
-Good heavens! It works.
-I-I like it.
TIM: I can't wait to see it
on your model.
BRIK:
Thank you.
-Laurence.
-Hello, Tim.
-How are you?
-Happy seeing this.
I was inspired
by the leather Chesterfield
sofa that they had over there.
-So this is all leather?
-Yeah.
I love this quilting effect.
It's really beautiful, and
the proportions are just right.
-Thank you.
-Oh, I'm gonna leave you alone.
-The clock is ticking,
but this is... -I know.
-spectacular.
-Thank you.
Last night, I was inspired by
-the pineapple copper bowl.
-Mm-hmm.
-How the water
was drizzling down it. -Mm-hmm.
Personally,
it looks like a costume.
It looks like
you're trying too hard.
I fundamentally
don't understand it.
MAH-JING:
Well, right now,
the house is shaking.
I need to figure out
what I'm going to do next,
'cause going home
ain't an option.
I'm gonna go back to
the drawing board and figure out
a few things,
and I will see if I can make
-a different take on it.
-All right. Carry on, carry on.
All right. Thank you.
ROBERI:
Um...
you seen this fabric
I found at Mood?
It looks like...
Missoni meets Navajo blanket.
It's not what I would associate
with luxurious
c*ck party dress.
Think about reconceiving,
doing something afresh.
I'll think about it.
Thank you, Tim.
Cornelius, I'm having déjà vu.
-[laughing]: Hi, Tim.
-Have we not seen this before?
CORNELIUS: You have seen
this print before.
TIM:
This looks like... sportswear.
-Does it?
-Mm-hmm.
Fudge muffins!
I have to scrap my dress.
This is crazy right now.
TIM:
Tasha?
-Yes, sir?
-Hi.
[sighs heavily]
What bothers you about it?
-It doesn't say "adult woman."
-Mm-hmm.
It doesn't say "sophisticated."
It reads too simple,
like too basic?
And too day.
My after 5:00 girl is...
She's still casual-looking.
I mean, you could use
a dark denim
and do a fabulous
c*ck dress.
-And I have that.
-You should just take this denim
-and let it speak to you.
-Okay.
Don't push street
into the c*ck.
-Push c*ck into the street.
-Gotcha.
And what happens to it.
And you're gonna tell us.
-Thank you.
-Thank you.
TIM:
Nathalia.
Wow. Talk to me.
I was really, really inspired by
the chandeliers
and the pineapple pink color.
And I remember seeing
this fabric, so...
-How much was this?
-It was $250 for one yard,
-so I got half a yard,
and, um... -Good God!
TIM: Do you think
this looks luxurious?
-I do. -How are you going
to respond if the judges
say to you that it looks
like an ice-skating outfit?
[gasps]
Oh, is it the neckpiece?
The neckpiece?! No!
It's the bedazzling.
It's as though
you're going out on the ice, and
you're putting on a show.
-[sighs]
-I don't want you to go home,
but this has "pack my bags"
written all over it.
What the [bleep]?
TIM:
All right, designers.
I was not expecting
to walk into this scenario of
approximately half of you really
understanding this challenge,
and the other half...
sort of at sea.
And we have four hours remaining
in the workday.
I have just left a few of you,
saying, "Start all over again."
You have to have something
to walk that runway, so,
-make it work.
-CORNELIUS: Half the designers
are not hitting the mark
with this one,
and we really need
to turn it up.
-Yeah. That makes it look
expensive. -Ooh.
[whispers]:
Oh, Jenni, thank you!
NATHALIA:
Jenni has extra lining
that looks really good
under my beaded fabric.
-It's gonna look classy with
this fabric. -Oh. I love you.
NATHALIA:
I think that
I can save this look if I, like,
work really hard right now.
DEXTER:
Looky, look!
-Ooh!
-Look at this zipper.
-Zippers! That's beautiful.
-Right?
♪ ♪
Hey!
I'm so excited!
Yeah, it's really, really fun.
Just slide in there.
-What's the challenge today?
-c*ck. After 5:00.
Being that my dress is plain,
it has to be
-the perfect fit.
-Turn to the side.
It has to be... impeccable.
Girl, I'm gonna do your hair,
like, spikey-like.
-Girl, you got hips! All right.
-[giggling]
Maybe I'll pleat it all the way
around and then do, like,
some high-low thing so it looks
-a little bit more dramatic.
-DEXTER: Yeah, we're good.
I'm going to drop
the lining in this b*tch.
[chuckles]
ROBERI: My party girl is not
this... flashy woman.
She's more... sophisticated.
I really like the shape.
I'm going to change
the whole silhouette,
but try and keep...
simplicity of lines.
Yeah, I've been sewing for,
like, four hours now.
Just hand stitching.
[muffled exclamation]
-Yes!
-Thank you, models!
[Mah-Jing blowing kisses]
NATHALIA: I pray to God
I just make a save.
It's crazy 'cause
I have so many ideas...
-Uh-huh.
-and then I, like, chose to do
the, like, worst one.
NATHALIA: Everything on this
dress has to handsewn.
MAH-JING: An hour!
Oh my God!
DEXTER: It's a c*ck dress.
This is right.
Just style the [bleep]
out of it.
Why you trippin'? [chuckles]
Girl, get outta that cranium.
Toss a bracelet on there
and call it a day.
Let's go home. I'm tired.
DEXTER:
Bye! [laughs]
Good night, workroom.
I wish I could stay all night
and finish my dress.
I mean, like, honestly,
I know I'm [bleep].
[horns honking]
Good morning, designers.
ALL:
Good morning.
TIM:
I suspect that most,
if not all of you, have a great
deal to do this morning.
-NATHALIA: Yes.
-CORNELIUS: Yes. -RIK: Yes.
TIM: Your models
are coming in soon.
You will have an hour
to send them to
the Sally Beauty studio
and the Mary Kay
color and design studio.
Use that JustFab accessories
wall thoughtfully!
There's a lot going on in here.
All right?
-We're gonna have a fabulous
runway show? -ALL: Yes!
-DEXTER: Excited.
-TIM: Yes! All right. Thank you.
CORNELIUS:
I just have to think positive
-and everything will work out.
-You'll be okay.
Just get it together.
Ugh!
This fabric is a nightmare.
I think we're all, like...
we don't know.
-Frantic?
-You know?
It's hard to...
crank out luxury.
DEXTER:
Hi.
What's up, what's up, what's up?
MAH-JING: I need my lace
complete. I'm praying
I make a good enough impression
where at least I'm safe.
Yes!
Yeah!
[loud clattering]
-LUIS: Hi.
-RIK: Hi!
Kind of just want to play
on her natural beauty.
I've been doing more of
a Lux texture on the lip.
-This has a creaminess to it.
-Mm.
-[camera shutter clicks]
-Sounds good. -Yeah.
Yeah, I think just the darkest
you can get it.
As long as we get
the shade right,
then I can take a really dark
plum liner
so i-it gets darkerer.
-[camera shutter clicks]
-Perfect. -Okay.
I was thinking a
bold wing line, black.
LUIS:
Got it.
I can give a little bit
of silver here,
and then the wing line
on the outer portion.
-[camera shutter snaps]
-Perfect. Thank you so much!
ROBERI:
I want it to be luxurious
but... subtle.
Why don't we do something
super on-trend right now?
Like a soft, cool
beach wave, but not textured.
-Perfect.
-She looks young.
-[camera shutter clicks]
-She looks cool and hip. -Yeah.
-A part in the middle.
-Okay.
Slick down behind her ears.
And it's just smooth
and straight.
Just highlight
this gorgeous face.
-[camera shutter snaps]
-Yes. -Got it.
I just want to make it
really nice, voluptuous.
Tight in the curls
and call it a day.
Va-va-voom!
[camera shutter clicks]
Oh, God...
Designers and models,
in ten minutes,
we're going down to the runway.
You look fantastic,
goodness.
[both laugh]
JENNI:
Laurence, this is so nice.
Laurence's look
is pretty kick-a*s,
and it has just enough
fun in the front.
Her look could possibly win.
Oh, it looks so good.
LAURENCE:
I love this one.
It's my favorite.
-Sorry.
-JENNI: You need an extra hand?
NATHALIA:
I might need help sewing her in.
JENNI: She knows that that
wasn't a really good
fabric choice.
Pull it up.
It's actually 100% of
a possibility of her going home.
Oh, my God, my hands
are so sweaty.
Designers and models,
we're heading down
to the runway, everyone.
-Yay!
-Follow me, please.
It feels like it'll stay?
Okay.
-[laughs]
-I'm not saying anything.
I'm just looking.
All right, that's it.
Mmm.
Hi, everybody,
and welcome to the runway.
As you know in fashion,
one day, you're in,
and the next day,
you're out.
There are 11 of you here,
and after tonight,
there will be ten.
You went to a press event
at the Absolut Elyx House.
-It was beautiful, right?
-Mm-hmm. -Yeah.
We asked you to make
a luxurious c*ck dress
showcasing your point of view.
Your experience at the loft
and the decor that surrounded
you served as your inspiration.
Dexter, since you are the winner
of the last challenge,
you have immunity
and cannot be eliminated today.
All right, Let's say hello
to our judges.
First, we have Creative Director
of Brooks Brothers Women
and fashion designer, Zac Posen.
-Hi, designers.
-ALL: Hi.
Creative Director for
Marie Claire magazine,
Nina Garcia.
-Hi, everyone.
-ALL: Hi, Nina.
And today's guest judge,
actress and model,
Emily Ratajkowski.
Welcome!
Hi, designers.
Also, we have Tim Gunn here
for the runway show.
[kisses]
As you know, he is your mentor
and will not be
judging your looks.
That said,
he has the Tim Gunn save.
If at some point during
the competition,
he disagrees with the judges,
he can bring that
eliminated designer
back to the show.
We also have
an anonymous runway show.
That means the judges
do not know which designer
created which look.
All right, let's start the show.
♪ ♪
LAURENCE: I definitely
think mine stands out.
I think I've done a good job
on this one
and I actually want to wear it.
I'm very happy.
RIK: I feel that I took
a risk with the color
and working with leather
for the first time.
For a c*ck dress,
it was very unconventional.
But I definitely think
I pulled this off.
Nice job, Rik.
JENNI: I am so enthused
with what I see.
I'm just following
this glow of gold
walk down the runway.
And the sparkle
is hitting lights
and it's twinkling
in just the right places.
Maybe I'll just be the
next c*ck dress designer.
ERIN:
I'm feeling really good.
I think that she definitely
is standing out.
I'm feeling very confident.
And I'm pretty sure mine's
in the top three.
♪ ♪
TASHA:
I'm very proud of my look,
especially being that
I pulled it off
with the small amount
of fabric I have.
♪ ♪
Who doesn't want a little black
dress for a c*ck party?
I feel like my look is cool.
♪ ♪
CORNELIUS:
I do like my look
walking down the runway
and it's most definitely
a c*ck dress.
But I don't know how the judges
are gonna feel about it.
♪ ♪
NATHALIA:
I feel like I got it together.
This is definitely not
what I envisioned,
but it looks really good
on the runway.
I feel like I'm gonna be okay.
♪ ♪
BRIK:
I'm thinking,
"Brik, you did it."
It has a little bit
of a retro, future vibe.
I love it.
BRIK:
The fit is on point.
The back is sexy.
I'm really happy
with this look.
♪ ♪
MAH-JING:
I like the way it looks.
Could it be a little tighter?
Yes.
But overall, with the time
I had...
it looks good on her.
I'm relieved.
♪ ♪
ROBERI:
She looks amazing.
The way she moves
in the dress is gorgeous.
Hopefully, the judges
are going to be very pleased
with the fit.
I'm... very happy
with the results.
It looks like a painting.
♪ ♪
DEXTER:
I'm really proud of my look.
I think it looks like hot sex
on a platter.
I'm very, very confident
that Erin and I
are gonna be in the top.
She's like...
fringe with benefits.
[laughter]
Designers, you were clearly
inspired by this challenge.
Some of you struggled, however.
If I call your name,
please step forward.
Laurence.
Nathalia.
Jenni.
Tasha.
Rik. Erin.
If I have not called
your name... congratulations.
Your scores have qualified you
to move onto the next round.
But before you go...
Dexter.
You are so very lucky
that you have
immunity this week.
Yeah. Today was a big
disappointment.
It felt really
down-market and
extensions that needed
to be chopped.
We need to raise
the imagination level.
-She was a hoochie mama.
-ZAC: Yeah.
I'll take that.
And I'll work on it. Thank you.
HEIDI:
Guys, you can leave the runway.
-Thank you.
-All right. Thank you.
HEIDI:
The six of you
have the highest...
and the lowest scores.
One of you will be named
the winner...
and one of you will be out.
Nathalia, tell us about
your inspiration
and your look.
So, I drew inspiration
from the chandeliers
in the, um, loft.
And when I saw them,
I immediately thought
of this fabric
that I saw at Mood.
When I think of luxury,
I think of beaded fabrics
and sequins.
And then for the under part,
I did a bustier
for the top to hold it up,
and just a simple pencil skirt
to go under.
I don't like this look at all.
It reminds me of, like, a, uh,
teen prom dress from the mall
that was really inexpensive.
It doesn't look luxurious
at all.
Can you turn around?
It's crooked to one side.
It just looks like
some cheap fabric
with some very cheap lining.
It is the opposite of luxurious.
I-I'm not making excuses,
but I did create this in, like,
less than four hours.
I was a little bit overambitious
with the fabric because I did
have to sew all the seams
by hand.
So, this is better than
what I had before.
Emily, what do you think?
I like this one more
than the other judges.
I think it's creative
and I-I saw a lot of things
on the runway that didn't
excite me and didn't stand out.
I can definitely tell
that it was rushed,
especially in the skirt,
but I don't think it's as bad
-as-as you guys do.
-Thank you.
Ladies... I disagree today.
I-I agree with Emily.
We're on the same page.
We're on
the same page.
Thank you.
The whole runway was
quite disappointing to me.
I think
the imagination level needs
to go way up.
So grading on the curve,
I think you actually chose
a smart textile.
Obviously, the sewing
is incredibly sloppy, but I
think there's interesting ideas
of transparency that
you were going for.
So, I think the idea behind it
represents
a space very well.
Thank you so much.
Rik, tell us about your look.
So, at the lounge in the press
party, I was really inspired
by the aprons that
the bartenders were wearing,
and I kind of wanted to play
-on that masculine energy.
-Ah!
The woman that I was
kind of going for,
you know, doesn't wear
feathers, beading,
so I just wanted the color
to pop and the dress
to pop, as well.
I love this piece.
Um, I could totally see myself
wearing it on a red carpet
or out with friends.
I think the orange is, you know,
a brave choice,
but it really works.
And that material doesn't look
easy to work with,
but it fits her very well.
It's nice.
And you know what?
I love the fact that
you really thought
out of the box
for this, and I could see this
as a dress for a woman
who is very confident...
-Mm-hmm.
-...and can pull this off.
I even like the fact that
you made it an A-line,
and it just holds so well.
It's so beautifully made.
I think this dress
is a real eye-catcher.
Not a lot of women
have something like that
-in their closet.
-Mm-hmm.
So you really created
something new and I like that.
I give it a high score.
Thank you.
You were very smart.
You picked a great
Courage-type leather.
And it definitely
stood out today.
Breath of fresh air.
[whispers]:
Thank you.
Laurence.
I was inspired
by the leather couches.
In particular,
the Chesterfield one.
And I've decided to go
with a "Chesterfield" dress.
So I used, uh, leather
and, uh, some heavy silk
for the bottom of the dress.
Loved it.
I absolutely love this dress.
I totally understand
the reference,
and you cut one sharp,
mean shoulder.
Thank you. I try.
I love this dress, as well.
She looks super elegant.
It definitely has
your signature shoulder.
It kind of plays
with hard and soft.
You know,
how it still looks very
feminine, but then
the leather up top is hard.
So, the sweet
and the hardness together
I really like.
This is the perfect,
little, black dress.
It didn't need any trappings
because it's all there
in the beautiful,
impeccable tailoring.
-And then the back is...
-Yeah.
...breathtaking.
You have a very
strong point of view.
And I knew immediately
it was yours.
So, that is such a plus
for a designer.
EMILY:
I love this dress, as well.
It looked like something
that I could wear right away
because of how well
it's tailored.
I think the black is
an obvious choice for c*ck.
That would be my only critique.
But it just looks
so much more expensive
than any of
the other dresses we saw.
Thank you.
Tasha, tell us about your look.
I was trying
to pretty much mesh,
uh, street and c*ck,
uh, for my girl, 'cause
she wouldn't wear, like,
the beads and the glamour.
It'd be more of a denim
or something like that
because it is street,
so that's what
my inspiration was.
The fit is off.
The sash to add the bling
just feels el cheapo.
And it really doesn't
show creativity.
NINA:
It is just a black dress
that you put a piece of ribbon
at the waist.
I can't even tell you
there's a lot of great tailoring
because I don't see that,
either.
I respect that.
Thank you.
It's the most unfinished-looking
piece that I saw today.
I almost think the dress would
be better without the ribbon.
And it's too much
with the earrings
and the choker and the shoes,
but it shows me that
you were aware that the dress
was too simple.
HEIDI:
Erin.
I was really inspired
by the copper.
Their whole, like,
signature metal.
And then I also really loved
the flamingo bathroom.
So, I kind of wanted
to just take the feathers
from that and, um,
I wanted to focus a lot on fit,
which isn't always
my strongest point,
so that was a big focus
-for me on this one.
-[exhales slowly]
Is she going to a c*ck party
or a costume party?
It is so... overdone.
She has wings.
It kind of looks silly
and funny in a way.
It doesn't look luxurious,
you know?
It goes the opposite.
I wrote,
"Priscilla,
Queen of the Swamp."
Um...
I think the copper
and the textures
are very representative
of the space that we were in,
but altogether,
there's not much
imagination here.
Can she turn?
Cheap and feathery.
Feathers are hard always.
With the material, and
the feathers and the sequins,
it's too much.
I was really surprised
when this turned out
to be your look.
It looks a little bit like
a costume from The Lion King.
Jenni, tell us about your
inspiration and your look.
I was really inspired by, of
course, the copper, but as well
as the other... metallics that
they had there, such as gold.
I'm a huge fan of gold
and there was also a lot
of sparkle in the room.
It almost brought me
back to, like,
what a speakeasy
would look like,
but a little more modern.
So, I tried creating something,
like, um, that I would wear
to a modern speakeasy.
I have to be honest,
I actually
was not thinking that was you
who created this dress, Jenni.
I actually thought it was you.
-ZAC: Me, as well.
-HEIDI: Erin.
And you know why that is?
It's because of the way
you bedazzled it.
Because that is usually
a technique that Erin would use.
I feel like that is something
that you maybe...
[clucks tongue]
...copied from her a little bit.
It might have been
a subconscious...
-pick up, but, um...
-Well, that's a good thing.
You're inspiring each other.
It's all about growth, right?
And I have to say, Jenni,
you really worked it out.
I love the easy, simple,
loose silhouette of it.
It's very sexy because it has
that low "V", which I love.
I also love the choker part
around the neck,
in that you have some
embellishment there, as well,
so it kind of crawls up on her.
I love how simple
the hair is today
with the smoky eye.
You know, she looks... great.
Thank you.
This was a beautiful fabric
and I think you were smart
in the way you used it.
Of all the pieces today, this is
what I would photograph
in that space sitting there.
I totally get
the speakeasy reference there,
but in no way does
it feel vintage.
-Thank you. -It has the ease
of a 1920s dress,
but totally today.
Thank you.
Okay, we've heard
what you had to say.
We're going to have
a little chat,
and then I'm going to call you
back onto the runway.
Thank you.
♪ ♪
HEIDI: The winner of
Project Runway will receive
$100,000 to launch their line,
a year's supply
of Sally Beauty products
along with $25,000 in cash,
travel and hotel accommodations
to inspiring destinations
around the world from
Best Western Hotels & Resorts
a new Lexus I.S.,
from Mary Kay, an entire year's
worth of beauty products
for their fashion shows,
and professional makeup
artist services
for their debut show.
A complete sewing
and crafting studio
from Brother sewing
and embroidery
and the winning designer
and model will receive
a fashion spread
in Marie Claire magazine.
♪ ♪
Hi, Tim.
Hi, Heidi, Zac, Nina, Emily.
Some are looking good
and some are looking
-not so good. -Would you like
to begin with Karina,
-wearing Nathalia?
-Yeah. -Sure.
I'm really surprised,
Emily and Zac,
-that you two really like this.
-NINA: Oh!
It looks like she took
the chandelier
[laughing]: and she just tried
to plop it on her.
It's shocking she made
this in four hours.
It looks like she made
it in 30 minutes.
Yes, agreed.
I just appreciate that she tried
-a different... thing.
-ZAC: Me, too.
-With something strapless,
some skin. -Mm-hmm.
-Yeah.
-A back piece, but overall,
yes, this is a hot, hot mess.
Alysia is wearing Erin.
-Whoa.
-Oh, those feathers.
And it's the fabric.
This was one of the worst
dresses today
that we saw on the runway.
You know, we have to be fair,
one day, you're in,
-the next day, you're out.
-Yup.
She is on the chopping
board today.
We have Alla wearing Tasha.
NINA:
So this is denim?
This is a ponte jersey.
So it's two different materials.
-And then what is...
-Denim
-and then this...
-This is so weird.
I see a lack of-of imagination
and creativity here.
I don't see very much
use of technique,
understanding of fabric.
I... I'm at a loss.
And the earrings and the shoes.
It's too much.
We had Tirzah wearing Rik.
HEIDI:
Rik did a great job.
-We loved it.
-We see the reference...
And this-this--
-the-the little...
-...of the bartenders.
-Yes.
-This is great, to the seam.
The irony of the apron
for the c*ck dress.
-It's just more modern.
-It is.
More unexpected.
She probably didn't need
this grosgrain because
-it was gonna open up.
-ZAC: Yeah, listen, the tricks
are here, the outside zipper,
the grosgrain, the halter,
but it all works.
Nice, solid job.
And we have Kristy
wearing Laurence.
-Wow.
-Yay!
Yeah, this is amazing up close.
-Wow.
-Amazing. I mean,
look at the detail
of the sleeve.
You know, this dress
is made from $300.
[chuckles]
and it looks like
a $2,000 dress.
It just works.
Lais, wearing Jenni.
This I love.
It's very beautiful,
and the shape.
I love the length,
I love that it's not tight.
I love this, but I do think
that Jenni is really stealing
some of Erin's technique.
I mean, I like the choice
that she did in the sequining.
I think there's some sensitive
placement of embroidery here,
which really takes artistry.
Like this right here.
It's beautiful.
It's like a collage.
I think it is very high fashion.
Very high-end.
Made with $300.
She spent a lot of time,
and it paid off.
HEIDI: I think it's gorgeous.
I would wear that.
Let's talk about
the design stuff
we did like.
Let's talk about Laurence.
She nailed this one.
EMILY: The whole dress,
the length, the back,
this line right here
was gorgeous.
I do want to see something more
than the shoulder from her.
Of course, now we've seen it.
We've seen it in a jacket,
we've seen it in
this great dress.
I'm just afraid now
we're gonna see it
in the denim version.
Okay, let's talk about Jenni.
It is so feminine, right?
It's an entrance dress.
Without being skin-tight.
-Yes, without being skin-tight,
-Yes.
or too flashy.
It is just great.
Let's talk about the designs
that we didn't like.
Oh, the beaded thing
was shoddy and shocking.
HEIDI: The problem with Nathalia
is she just fell in love
with that fabric.
Like Erin's, I'm sure
that was expensive.
I'm sure that fabric
was expensive,
I'm sure the feathers
were expensive.
-But it looked so cheap.
-ZAC: Yeah.
And it does look super cheap.
-Feel bad for the birds.
-What about Tasha, though?
I mean, that didn't
even try to do something.
-ZAC: Yeah.
-HEIDI: It was uninspiring,
and there was no design here.
But I would still wear Tasha's
over Nathalia's.
HEIDI:
So, I don't know.
Do we want to send someone home
with no design, like Tasha?
Or do we send someone home
who over-designed,
or over-bedazzled,
like Nathalia or Erin?
Okay, so we've made
our decision.
Let's bring them back out.
The six of you
had the highest
and the lowest scores.
One of you will be the winner
and one of you will be out.
Jenni.
Congratulations, you are
the winner of this challenge.
[applause]
My heart.
[gasps]
Thank you so much.
That's crazy.
Jenni, this also means
that you have immunity
for the next challenge
and cannot be eliminated.
-Thank you. -As the winner
of this challenge,
Absolut Elyx is rewarding you
with a dinner and Elyx c*ck
at one of New York's hottest
restaurants for 12 people.
[softly]:
Oh, my God.
My little heart is like...
Jenni, you're in.
-You can leave the runway.
Thank you. -Thank you.
I did this all on my own.
It's my first solo win.
I never thought that
I could, like,
pick myself up to this speed.
[indistinct conversation]
-[gasps]
-You won? -Yeah!
-Jenni, congratulations.
-Congrats. -I'm so shocked.
-Oh, my God.
-Congratulations.
I mean, I'm not shocked,
but I'm shocked, you know?
Rik, Laurence, great job.
You're both in.
You can leave the runway.
-Thank you guys.
-Thank you.
Tasha.
We were disappointed
with your dress.
It had very little design
and creativity to it.
And the cheap, sparkly sash
made it even worse.
Nathalia, we did not all agree
on your look.
Some of us thought it was
poorly made and tacky,
but some of us appreciated
your effort more.
But what we did all agree on
was that
the end result was a mess.
Erin, your dress was
a low point today.
It felt costumey,
over-designed,
and a bit bizarre.
And as you know,
one day, you're in,
and the next day, you're out.
Erin....
...you're in,
you can leave the runway.
Thank you.
Nathalia, Tasha,
one of you will be out.
Nathalia...
...you're in.
[exhales]
Thank you so much.
Thank you.
I promise I won't
let you guys down again.
-Sorry, Tasha.
-That's all right.
Congratulations.
Tasha, I'm sorry,
that means you're out.
We really enjoyed
having you here.
This has been
a huge, huge blessing.
And a great platform for me.
Auf Wiedersehen.
-Good luck to you.
-Thank you. Thank y'all.
-Thank you. Good luck.
-Good luck!
I'm really proud of myself
for getting this far.
I'm grateful, grateful,
grateful,
so grateful to God
for this opportunity.
I'm going home.
-Don't cry, 'cause I wasn't
going to cry. -[crying]
No.
-Don't cry.
-Tashy!
I'm gonna miss you so much.
-I think Mah-Jing making me cry
'cause... -Sorry!
Ah, it's happy tears. I'm good!
All the things that I went
through to be on this.
Being homeless. Just trying
to keep my dream alive
of being a designer,
and I never gave up.
And I made it here and I thank
God for the opportunity.
How are you doing?
-We love you.
-I was good
until Mah-Jing fell apart.
Mah-Jing is crying
about everything.
-I know, but look...
-[laughter]
I came in, I was sure I wasn't
going to cry until he did that.
Good things will happen for you.
And we're sending positive
thoughts, okay?
Thank you so much.
Gonna send you to the workroom
to clean up your space.
-Okay. All right. Bye, y'all.
-Thank you, Tasha.
ALL:
Bye, Tasha.
I learned a lot being here,
so I just wanted to
amp everything up, take it to
the next level and keep pushing.
That's all I can do.
This just was part
of the journey.
HEIDI:
Next time on Project Runway...
I feel like you need
a little excitement.
-Turn upside down.
-[screaming]
-[laughing]
-I am sending you on a trip.
[screaming]
-[roaring]
-[screaming]
[screaming]
It's so heavy.
I really need to get
this [bleep] together.
You should go home
for something that you love.
We're going down to the runway.
Gonna be so good.
I... love her.
It looks like she got sick
on the ride.
So ugly.
Nobody wants an expanding butt.
HEIDI: Visit mylifetime.com
to learn more
about the fashion you've seen
on tonight's show.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
15x06 - There IS Crying in Fashion
Watch/Buy Amazon
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.